==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/CollectiveRunUI/src/com/clustercontrol/collectiverun/view/action/HistoryFilterAction.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.collectiverun.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.bean.Property;
import com.clustercontrol.collectiverun.dialog.HistoryFilterDialog;
import com.clustercontrol.collectiverun.view.HistoryView;

/**
 * 򸡺ɽ󥯥饹
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class HistoryFilterAction implements IViewActionDelegate {
    protected IViewPart m_view;

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart view) {
        m_view = view;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        if (action.isChecked()) { // ܥ󤬲줿

            HistoryFilterDialog dialog = new HistoryFilterDialog(PlatformUI
                    .getWorkbench().getActiveWorkbenchWindow().getShell());

            HistoryView view = (HistoryView) m_view
                    .getAdapter(HistoryView.class);

            //ե륿ɽ
            if (dialog.open() == IDialogConstants.OK_ID) {
                // ӥ塼ե륿⡼ɤɽ
                Property property = dialog.getInputData();
                view.setFilterCondition(property);
                view.update();
            } else {
                action.setChecked(false);
            }
        } else { // ܥä
            // ӥ塼̾⡼ɤɽ
            HistoryView view = (HistoryView) m_view
                    .getAdapter(HistoryView.class);
            view.setFilterCondition(null);
            view.update();
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {

    }

}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/CollectiveRunUI/src/com/clustercontrol/collectiverun/view/action/HistoryFilterAction.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.collectiverun.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.bean.Property;
import com.clustercontrol.collectiverun.dialog.HistoryFilterDialog;
import com.clustercontrol.collectiverun.view.HistoryView;

/**
 * 履歴検索表示アクションクラス
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class HistoryFilterAction implements IViewActionDelegate {
    protected IViewPart m_view;

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart view) {
        m_view = view;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        if (action.isChecked()) { // ボタンが押された場合

            HistoryFilterDialog dialog = new HistoryFilterDialog(PlatformUI
                    .getWorkbench().getActiveWorkbenchWindow().getShell());

            HistoryView view = (HistoryView) m_view
                    .getAdapter(HistoryView.class);

            //履歴フィルタダイアログを表示
            if (dialog.open() == IDialogConstants.OK_ID) {
                // 履歴ビューをフィルタモードで表示
                Property property = dialog.getInputData();
                view.setFilterCondition(property);
                view.update();
            } else {
                action.setChecked(false);
            }
        } else { // ボタンが戻った場合
            // 履歴ビューを通常モードで表示
            HistoryView view = (HistoryView) m_view
                    .getAdapter(HistoryView.class);
            view.setFilterCondition(null);
            view.update();
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {

    }

}
